==> openshift-model-config-6.5.1-sources.jar: io/fabric8/openshift/api/model/config/v1/SchedulerSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SchedulerSpecFluentImpl<A extends SchedulerSpecFluent<A>> extends BaseFluent<A> implements SchedulerSpecFluent<A>{
  public SchedulerSpecFluentImpl() {
  }
  public SchedulerSpecFluentImpl(SchedulerSpec instance) {
    this.withDefaultNodeSelector(instance.getDefaultNodeSelector()); 
    this.withMastersSchedulable(instance.getMastersSchedulable()); 
    this.withPolicy(instance.getPolicy()); 
    this.withProfile(instance.getProfile()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String defaultNodeSelector;
  private Boolean mastersSchedulable;
  private ConfigMapNameReferenceBuilder policy;
  private String profile;
  private Map<String,Object> additionalProperties;
  public String getDefaultNodeSelector() {
    return this.defaultNodeSelector;
  }
  public A withDefaultNodeSelector(String defaultNodeSelector) {
    this.defaultNodeSelector=defaultNodeSelector; return (A) this;
  }
  public Boolean hasDefaultNodeSelector() {
    return this.defaultNodeSelector != null;
  }
  public Boolean getMastersSchedulable() {
    return this.mastersSchedulable;
  }
  public A withMastersSchedulable(Boolean mastersSchedulable) {
    this.mastersSchedulable=mastersSchedulable; return (A) this;
  }
  public Boolean hasMastersSchedulable() {
    return this.mastersSchedulable != null;
  }
  
  /**
   * This method has been deprecated, please use method buildPolicy instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getPolicy() {
    return this.policy!=null ?this.policy.build():null;
  }
  public ConfigMapNameReference buildPolicy() {
    return this.policy!=null ?this.policy.build():null;
  }
  public A withPolicy(ConfigMapNameReference policy) {
    _visitables.get("policy").remove(this.policy);
    if (policy!=null){ this.policy= new ConfigMapNameReferenceBuilder(policy); _visitables.get("policy").add(this.policy);} else { this.policy = null; _visitables.get("policy").remove(this.policy); } return (A) this;
  }
  public Boolean hasPolicy() {
    return this.policy != null;
  }
  public A withNewPolicy(String name) {
    return (A)withPolicy(new ConfigMapNameReference(name));
  }
  public SchedulerSpecFluent.PolicyNested<A> withNewPolicy() {
    return new SchedulerSpecFluentImpl.PolicyNestedImpl();
  }
  public SchedulerSpecFluent.PolicyNested<A> withNewPolicyLike(ConfigMapNameReference item) {
    return new SchedulerSpecFluentImpl.PolicyNestedImpl(item);
  }
  public SchedulerSpecFluent.PolicyNested<A> editPolicy() {
    return withNewPolicyLike(getPolicy());
  }
  public SchedulerSpecFluent.PolicyNested<A> editOrNewPolicy() {
    return withNewPolicyLike(getPolicy() != null ? getPolicy(): new ConfigMapNameReferenceBuilder().build());
  }
  public SchedulerSpecFluent.PolicyNested<A> editOrNewPolicyLike(ConfigMapNameReference item) {
    return withNewPolicyLike(getPolicy() != null ? getPolicy(): item);
  }
  public String getProfile() {
    return this.profile;
  }
  public A withProfile(String profile) {
    this.profile=profile; return (A) this;
  }
  public Boolean hasProfile() {
    return this.profile != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SchedulerSpecFluentImpl that = (SchedulerSpecFluentImpl) o;
    if (defaultNodeSelector != null ? !defaultNodeSelector.equals(that.defaultNodeSelector) :that.defaultNodeSelector != null) return false;
    if (mastersSchedulable != null ? !mastersSchedulable.equals(that.mastersSchedulable) :that.mastersSchedulable != null) return false;
    if (policy != null ? !policy.equals(that.policy) :that.policy != null) return false;
    if (profile != null ? !profile.equals(that.profile) :that.profile != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(defaultNodeSelector,  mastersSchedulable,  policy,  profile,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (defaultNodeSelector != null) { sb.append("defaultNodeSelector:"); sb.append(defaultNodeSelector + ","); }
    if (mastersSchedulable != null) { sb.append("mastersSchedulable:"); sb.append(mastersSchedulable + ","); }
    if (policy != null) { sb.append("policy:"); sb.append(policy + ","); }
    if (profile != null) { sb.append("profile:"); sb.append(profile + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withMastersSchedulable() {
    return withMastersSchedulable(true);
  }
  class PolicyNestedImpl<N> extends ConfigMapNameReferenceFluentImpl<SchedulerSpecFluent.PolicyNested<N>> implements SchedulerSpecFluent.PolicyNested<N>,Nested<N>{
    PolicyNestedImpl(ConfigMapNameReference item) {
      this.builder = new ConfigMapNameReferenceBuilder(this, item);
    }
    PolicyNestedImpl() {
      this.builder = new ConfigMapNameReferenceBuilder(this);
    }
    ConfigMapNameReferenceBuilder builder;
    public N and() {
      return (N) SchedulerSpecFluentImpl.this.withPolicy(builder.build());
    }
    public N endPolicy() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/SchedulerSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SchedulerSpecFluentImpl<A extends SchedulerSpecFluent<A>> extends BaseFluent<A> implements SchedulerSpecFluent<A>{
  public SchedulerSpecFluentImpl() {
  }
  public SchedulerSpecFluentImpl(SchedulerSpec instance) {
    if (instance != null) {
      this.withDefaultNodeSelector(instance.getDefaultNodeSelector());
      this.withMastersSchedulable(instance.getMastersSchedulable());
      this.withPolicy(instance.getPolicy());
      this.withProfile(instance.getProfile());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String defaultNodeSelector;
  private Boolean mastersSchedulable;
  private ConfigMapNameReferenceBuilder policy;
  private String profile;
  private Map<String,Object> additionalProperties;
  public String getDefaultNodeSelector() {
    return this.defaultNodeSelector;
  }
  public A withDefaultNodeSelector(String defaultNodeSelector) {
    this.defaultNodeSelector=defaultNodeSelector; return (A) this;
  }
  public Boolean hasDefaultNodeSelector() {
    return this.defaultNodeSelector != null;
  }
  public Boolean getMastersSchedulable() {
    return this.mastersSchedulable;
  }
  public A withMastersSchedulable(Boolean mastersSchedulable) {
    this.mastersSchedulable=mastersSchedulable; return (A) this;
  }
  public Boolean hasMastersSchedulable() {
    return this.mastersSchedulable != null;
  }
  
  /**
   * This method has been deprecated, please use method buildPolicy instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getPolicy() {
    return this.policy!=null ?this.policy.build():null;
  }
  public ConfigMapNameReference buildPolicy() {
    return this.policy!=null ?this.policy.build():null;
  }
  public A withPolicy(ConfigMapNameReference policy) {
    _visitables.get("policy").remove(this.policy);
    if (policy!=null){ this.policy= new ConfigMapNameReferenceBuilder(policy); _visitables.get("policy").add(this.policy);} else { this.policy = null; _visitables.get("policy").remove(this.policy); } return (A) this;
  }
  public Boolean hasPolicy() {
    return this.policy != null;
  }
  public A withNewPolicy(String name) {
    return (A)withPolicy(new ConfigMapNameReference(name));
  }
  public SchedulerSpecFluentImpl.PolicyNested<A> withNewPolicy() {
    return new SchedulerSpecFluentImpl.PolicyNestedImpl();
  }
  public SchedulerSpecFluentImpl.PolicyNested<A> withNewPolicyLike(ConfigMapNameReference item) {
    return new SchedulerSpecFluentImpl.PolicyNestedImpl(item);
  }
  public SchedulerSpecFluentImpl.PolicyNested<A> editPolicy() {
    return withNewPolicyLike(getPolicy());
  }
  public SchedulerSpecFluentImpl.PolicyNested<A> editOrNewPolicy() {
    return withNewPolicyLike(getPolicy() != null ? getPolicy(): new ConfigMapNameReferenceBuilder().build());
  }
  public SchedulerSpecFluentImpl.PolicyNested<A> editOrNewPolicyLike(ConfigMapNameReference item) {
    return withNewPolicyLike(getPolicy() != null ? getPolicy(): item);
  }
  public String getProfile() {
    return this.profile;
  }
  public A withProfile(String profile) {
    this.profile=profile; return (A) this;
  }
  public Boolean hasProfile() {
    return this.profile != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SchedulerSpecFluentImpl that = (SchedulerSpecFluentImpl) o;
    if (!java.util.Objects.equals(defaultNodeSelector, that.defaultNodeSelector)) return false;

    if (!java.util.Objects.equals(mastersSchedulable, that.mastersSchedulable)) return false;

    if (!java.util.Objects.equals(policy, that.policy)) return false;

    if (!java.util.Objects.equals(profile, that.profile)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(defaultNodeSelector,  mastersSchedulable,  policy,  profile,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (defaultNodeSelector != null) { sb.append("defaultNodeSelector:"); sb.append(defaultNodeSelector + ","); }
    if (mastersSchedulable != null) { sb.append("mastersSchedulable:"); sb.append(mastersSchedulable + ","); }
    if (policy != null) { sb.append("policy:"); sb.append(policy + ","); }
    if (profile != null) { sb.append("profile:"); sb.append(profile + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withMastersSchedulable() {
    return withMastersSchedulable(true);
  }
  class PolicyNestedImpl<N> extends ConfigMapNameReferenceFluentImpl<SchedulerSpecFluentImpl.PolicyNested<N>> implements SchedulerSpecFluentImpl.PolicyNested<N>,Nested<N>{
    PolicyNestedImpl(ConfigMapNameReference item) {
      this.builder = new ConfigMapNameReferenceBuilder(this, item);
    }
    PolicyNestedImpl() {
      this.builder = new ConfigMapNameReferenceBuilder(this);
    }
    ConfigMapNameReferenceBuilder builder;
    public N and() {
      return (N) SchedulerSpecFluentImpl.this.withPolicy(builder.build());
    }
    public N endPolicy() {
      return and();
    }
    
  }
  
}
